'''
This module aims to tell you a story, which is only belong to Y and Y
'''
def ChapterOne():
    print('''
    【Headline:Start With Darkness】
    Many years ago, it's hard to find the date in detail.
    A spider was stuck in a abyss, and he was desperate and do not want to struggle for a bright future.
    Maybe you could ask why. The spider didn't know either.
    He lived with three other creatures, namely a fat white bear, a strong leopard and a swift hyena.
    As a spider, he found he was the smallest creature which is the most vulnerable within all four animals.
    Day by day, he gradually lost confidence and finally dropped into a dark abyss.
    ''')