from distutils.core import setup
setup(
    name = 'RomanceStory',
    version = '1.0',
    description='This module aims to tell you a story, which is only belong to Y and Y',
    author='Kryser',
    author_email='1053875540@qq.com',
    py_modules=['RomanceStory.ChapterOne','RomanceStory.ChapterOne']
)